@@ -186,7 +186,7 @@ interval.padding = 50, DB.info.flag = "DB") {
     if (!is.null(snp.blacklist)) {
         for (i in seq_along(snp.blacklist)) {
             blackBed <- try(import(snp.blacklist[i]))
-            if (class(blackBed) == "try-error") {
+            if (is(blackBed, "try-error")) {
                 .stopUserError("Could not import snp.blacklist ", snp.blacklist[[i]],
                     ":", blackBed)
             }    
@@ -216,6 +216,10 @@ interval.padding = 50, DB.info.flag = "DB") {
         flog.warn("Less than half of variants in dbSNP. Make sure that VCF %s", 
             "contains both germline and somatic variants.")
     }
+
+    # remove seqlevels we filtered out
+    seqlevels(vcf) <- seqlevelsInUse(vcf)
+
     list(
         vcf=vcf, 
         flag=flag, 
@@ -293,8 +297,12 @@ function(vcf, tumor.id.in.vcf, allowed=0.05) {
         }        
         if (!is.null(geno(vcf)$GT)) {
             cs <- colSums(geno(vcf)$GT=="0")
+            if (any(is.na(cs))) {
+                flog.warn("GT field in VCF contains missing values.")
+            }    
+            cs <- colSums(geno(vcf)$GT=="0", na.rm = TRUE)
             if (max(cs) > 0) return(which.min(cs))
-            cs <- colSums(geno(vcf)$GT=="0/0")
+            cs <- colSums(geno(vcf)$GT=="0/0", na.rm = TRUE)
             if (max(cs) > 0) return(which.min(cs))
         }
         if (!is.null(geno(vcf)$FA)) {
@@ -537,12 +545,12 @@ function(vcf, tumor.id.in.vcf, allowed=0.05) {
     vcf
 }
     
-.addCosmicCNT <- function(vcf, cosmic.vcf.file) {
-    if (!is.null(info(vcf)$Cosmic.CNT)) {
+.addCosmicCNT <- function(vcf, cosmic.vcf.file, Cosmic.CNT.info.field) {
+    if (!is.null(info(vcf)[[Cosmic.CNT.info.field]])) {
         flog.info("VCF already COSMIC annotated. Skipping.")
         return(vcf)        
     }
-    cosmicSeqStyle <- seqlevelsStyle(headerTabix(
+    cosmicSeqStyle <- .getSeqlevelsStyle(headerTabix(
         TabixFile(cosmic.vcf.file))$seqnames)
 
     vcfRenamedSL <- vcf
@@ -553,9 +561,9 @@ function(vcf, tumor.id.in.vcf, allowed=0.05) {
     # look-up the variants in COSMIC
     cosmic.vcf <- readVcf(cosmic.vcf.file, genome = genome(vcfRenamedSL)[1],  
         ScanVcfParam(which = rowRanges(vcfRenamedSL),
-            info="CNT",
-            fixed="ALT",
-            geno=NA
+            info = "CNT",
+            fixed = "ALT",
+            geno = NA
         )
     )
     ov <- findOverlaps(vcfRenamedSL, cosmic.vcf, type = "equal")
@@ -572,12 +580,12 @@ function(vcf, tumor.id.in.vcf, allowed=0.05) {
     }
     
     newInfo <- DataFrame(
-        Number=1, Type="Integer",
-        Description="How many samples in Cosmic have this mutation",
-        row.names="Cosmic.CNT")
+        Number = 1, Type = "Integer",
+        Description = "How many samples in Cosmic have this mutation",
+        row.names = Cosmic.CNT.info.field)
     info(header(vcf)) <- rbind(info(header(vcf)), newInfo)
-    info(vcf)$Cosmic.CNT <- NA
-    info(vcf)$Cosmic.CNT[queryHits(ov)] <- info(cosmic.vcf[subjectHits(ov)])$CNT
+    info(vcf)[[Cosmic.CNT.info.field]] <- NA
+    info(vcf)[[Cosmic.CNT.info.field]][queryHits(ov)] <- info(cosmic.vcf[subjectHits(ov)])$CNT
     vcf
 }
 
