@@ -86,7 +86,8 @@ col.snps = "#2b6391", col.chr.shading = "#f0f0f0", ...) {
         for (i in ids) {
             par(mfrow = c(1,1))
             plotAbs(res, i, type = "hist")
-            if (!is.null(res$input$vcf)) {
+            if (!is.null(res$input$vcf) && 
+                !is.null(res$results[[i]]$SNV.posterior)) {
                 plotAbs(res, i, type = "BAF", ...)
                 plotAbs(res, i, type = "AF", ...)
             }
@@ -161,7 +162,8 @@ ss) {
 .getVariantPosteriors <- function(res, id, max.mapping.bias = NULL) {
     r <- res$results[[id]]$SNV.posterior$posteriors
     if (!is.null(r) && !is.null(max.mapping.bias)) {
-        r <- r[r$MAPPING.BIAS >= max.mapping.bias,]
+        r <- r[r$MAPPING.BIAS >= max.mapping.bias & 
+               r$MAPPING.BIAS <= (2 - max.mapping.bias), ]
     }    
     r
 }
@@ -295,7 +297,7 @@ ss) {
 
     }    
     if (!is.null(max.mapping.bias)) {
-        idx <- idx & r$MAPPING.BIAS >= max.mapping.bias
+        idx <- idx & r$MAPPING.BIAS >= max.mapping.bias & r$MAPPING.BIAS <= (2 - max.mapping.bias)
     }
     if (!sum(idx)) {
         flog.warn("No variants to plot")
